@@ -16,7 +16,7 @@ build_time_vars = {'ABIFLAGS': '',
  'BLDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'i386-unknown-openbsd7.4',
+ 'BUILD_GNU_TYPE': 'i386-unknown-openbsd7.5',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
@@ -30,7 +30,6 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS_NODIST': '-flto -g -std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
-                            '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/local/include',
@@ -42,17 +41,16 @@ build_time_vars = {'ABIFLAGS': '',
                 "-I/usr/local/include/tk8.6 -I/usr/X11R6/include' "
                 "'--with-tcltk-libs=-L/usr/X11R6/lib -ltcl86 -ltk86' "
                 "'--enable-loadable-sqlite-extensions' '--with-lto' "
-                "'--enable-optimizations' '--prefix=/usr/local' "
-                "'--sysconfdir=/etc' '--mandir=/usr/local/man' "
-                "'--infodir=/usr/local/info' '--localstatedir=/var' "
-                "'--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' "
-                "'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' "
-                "'CPPFLAGS=-I/usr/local/include'",
+                "'--prefix=/usr/local' '--sysconfdir=/etc' "
+                "'--mandir=/usr/local/man' '--infodir=/usr/local/info' "
+                "'--localstatedir=/var' '--disable-silent-rules' "
+                "'--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' "
+                "'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/pobj/Python-3.9.18/Python-3.9.18/coverage.info',
- 'COVERAGE_REPORT': '/pobj/Python-3.9.18/Python-3.9.18/lcov-report',
+ 'COVERAGE_INFO': '/build/tmp/pobj/Python-3.9.19/Python-3.9.19/coverage.info',
+ 'COVERAGE_REPORT': '/build/tmp/pobj/Python-3.9.19/Python-3.9.19/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/local/include',
@@ -138,7 +136,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CURSES_H': 1,
  'HAVE_CURSES_HAS_KEY': 1,
  'HAVE_CURSES_IMMEDOK': 1,
- 'HAVE_CURSES_IS_PAD': 0,
+ 'HAVE_CURSES_IS_PAD': 1,
  'HAVE_CURSES_IS_TERM_RESIZED': 1,
  'HAVE_CURSES_RESIZETERM': 1,
  'HAVE_CURSES_RESIZE_TERM': 1,
@@ -522,16 +520,16 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'i386-unknown-openbsd7.4',
+ 'HOST_GNU_TYPE': 'i386-unknown-openbsd7.5',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
                    '/usr/local/include/python3.9 /usr/local/include/python3.9',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python3.9',
- 'INSTALL': '/pobj/Python-3.9.18/bin/install -c',
- 'INSTALL_DATA': '/pobj/Python-3.9.18/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/pobj/Python-3.9.18/bin/install -c -s -m 755',
- 'INSTALL_SCRIPT': '/pobj/Python-3.9.18/bin/install -c -m 755',
- 'INSTALL_SHARED': '/pobj/Python-3.9.18/bin/install -c -m 755',
+ 'INSTALL': '/build/tmp/pobj//Python-3.9.19/bin/install -c',
+ 'INSTALL_DATA': '/build/tmp/pobj//Python-3.9.19/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/build/tmp/pobj//Python-3.9.19/bin/install -c -s -m 755',
+ 'INSTALL_SCRIPT': '/build/tmp/pobj//Python-3.9.19/bin/install -c -m 755',
+ 'INSTALL_SHARED': '/build/tmp/pobj//Python-3.9.19/bin/install -c -m 755',
  'INSTSONAME': 'libpython3.9.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
@@ -642,10 +640,8 @@ build_time_vars = {'ABIFLAGS': '',
                              '-O2 -pipe -O2 -pipe -flto -g -std=c99 -Wextra '
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
-                             '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden -I/usr/local/include '
-                             '-fprofile-instr-use=code.profclangd '
                              '-I./Include/internal -I. -I./Include '
                              '-I/usr/local/include -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
@@ -653,25 +649,24 @@ build_time_vars = {'ABIFLAGS': '',
               '-O2 -pipe   -fPIC -O2 -pipe -O2 -pipe',
  'PY_CFLAGS_NODIST': '-flto -g -std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden -I/usr/local/include '
-                     '-fprofile-instr-use=code.profclangd -I./Include/internal',
+                     '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
                    '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -flto -g '
                    '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wstrict-prototypes '
+                   '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                   '-I/usr/local/include -fprofile-instr-use=code.profclangd '
-                   '-I./Include/internal -I. -I./Include -I/usr/local/include '
-                   '-fPIC -DPy_BUILD_CORE',
+                   '-I/usr/local/include -I./Include/internal -I. -I./Include '
+                   '-I/usr/local/include -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/usr/local/lib/ -flto -g '
-                    '-L/pobj/Python-3.9.18/Python-3.9.18 -L/usr/local/lib/',
+                    '-L/build/tmp/pobj//Python-3.9.19/Python-3.9.19 '
+                    '-L/usr/local/lib/',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-L/usr/local/lib/',
- 'PY_LDFLAGS_NODIST': '-flto -g -L/pobj/Python-3.9.18/Python-3.9.18 '
+ 'PY_LDFLAGS_NODIST': '-flto -g -L/build/tmp/pobj//Python-3.9.19/Python-3.9.19 '
                       '-L/usr/local/lib/',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
@@ -679,10 +674,8 @@ build_time_vars = {'ABIFLAGS': '',
                         '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -flto '
                         '-g -std=c99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
-                        '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden -I/usr/local/include '
-                        '-fprofile-instr-use=code.profclangd '
                         '-I./Include/internal -I. -I./Include '
                         '-I/usr/local/include -fPIC',
  'Py_DEBUG': 0,
@@ -693,7 +686,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/pobj/Python-3.9.18/Python-3.9.18',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.9.19/Python-3.9.19',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SHELL': '/bin/sh',
@@ -735,10 +728,11 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '-L/usr/X11R6/lib -ltcl86 -ltk86',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/pobj/Python-3.9.18/Python-3.9.18 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.9.19/Python-3.9.19 '
+               './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/pobj/Python-3.9.18/Python-3.9.18 ./python '
-               './Tools/scripts/run_tests.py',
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.9.19/Python-3.9.19 '
+               './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
@@ -760,8 +754,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/pobj/Python-3.9.18/Python-3.9.18',
- 'abs_srcdir': '/pobj/Python-3.9.18/Python-3.9.18',
+ 'abs_builddir': '/build/tmp/pobj/Python-3.9.19/Python-3.9.19',
+ 'abs_srcdir': '/build/tmp/pobj/Python-3.9.19/Python-3.9.19',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
